function EEP_SVSI=EEP_SVSI(varargin)



% 
%           THE EARLY EXCERCISE PREMIUM OF THE AMERICAN PUT OPTION
%                       IN AN AFFINE TWO FACTOR MODEL
%
%    Function:
%    
%           EEP = EEP_SVSI(Price, Strike, Maturity, Volatility, Interest, Dividend)
%
%
%    Inputs:
%
%           Spot - Price of the underlying
%
%           Strike - Option strike price
%
%           Maturity - Option time-to-maturity
%
%           Volatility - Volatility of the underlying
%
%           Interest - Interest rate
%
%           Dividend - Dividend rate (stock options)
%    
%    Outputs:
%            
%            Approximation for the Early Exercise Premium
%            Approximationb for the American Put Price
%            Approximation for the European Put Price   
%            Value-Maximizing Suboptimal Exercise Rule (y_bar in the paper)   
%            
%
%
% 
%    
%
%    Method:
%       
%          American put price is approximated by the maximum over prices of options
%          with suboptimal excercise rule(function P_SVSI based on a 5th order expansion).  
%          They were derived in Maple and copy-pasted to this code. For details, see 
%          Medvedev A. and O. Scaillet "Pricing American Options Under 
%          Stochastic Volatility And Stochastic Interest Rates"
%
%
%    Author(s): A. Medvedev
%    Date: 2008/01/23


if (nargin < 6)
    error('finfixed:cdprice:invalidInputs','Incorrect number of inputs.');

else
    Price = varargin{1};
    Strike = varargin{2};
    Maturity = varargin{3};
    Volatility = varargin{4};
    Interest = varargin{5};
    Dividend = varargin{6};
    
end



v=Volatility;
r=Interest;
S=Price;
K=Strike;
t=Maturity;
d=Dividend;

y0=log(K/S)/v/sqrt(t);
step=0.1;
y=y0;
P0=K-S;
while step>=0.001
    dir=1;
    search=1;    
    n=0;
    while (search==1)&(n<=1000)
        n=n+1;
        P1=P_SVSI(S,K,t,v,r,d,y+dir*step);
        if P1>P0
            y=y+dir*step;
            P0=P1; %American put
        else
            search=0;
        end

    end
    step=step/10;
    P1=P_SVSI(S,K,t,v,r,d,y-step);
    P2=P_SVSI(S,K,t,v,r,d,y+step);
    if P2>P1
        dir=1;        
    else 
        dir=-1;       
    end
    
end
    
EP=P_SVSI(S,K,t,v,r,d,10000); %European put


EEP=P0-EP; %Early excercise premium    







EEP_SVSI=[EEP,P0,EP,y]; 
        
end




    


