function P_SVSI=P_SVSI(varargin)
% 
%           PRICE OF THE OPTION WITH SUBOPTIMAL EXCERCISE BOUNDARY
%                       IN AN AFFINE TWO FACTOR MODEL
%
%    Function:
%    
%           P = P_SVSI(Price, Strike, Maturity, Volatility, Interest, Dividend, y)
%
%
%    Inputs:
%
%           Spot - Price of the underlying
%
%           Strike - Option strike price
%
%           Maturity - Option time-to-maturity
%
%           Volatility - Volatility of the underlying
%
%           Interest - Interest rate
%
%           Dividend - Dividend rate (stock options)
%
%           y - the critical level of normalized moneyness
%
% 
%    Model:
%
%           dS=(r(t)-d)*dt+sqrt(v(t))*dW1,
%
%           dv(t)=k_v*(v_bar-v(t))*dt+sigma_v*sqrt(v(t))*dW2,
%
%           dr(t)=k_r*(r_bar-r(t))*dt+sigma_r*sqrt(r(t))*dW3,
%
%           with: rho12*dt=dW1*dW2, rho13*dt=dW1*dW3.
%
%
%    Method:
%       
%          The price of an option with a suboptimal excercis boundary is computed using 
%          a short-maturity expansion up to the 5th order. The expression was derived 
%          in Maple and copy-pasted to this code.
%          For details, see Medvedev A. and O. Scaillet "Pricing American Options Under 
%          Stochastic Volatility And Stochastic Interest Rates"
%
%
%    Author(s): A. Medvedev
%    Date: 2008/01/23



if (nargin < 7)
    error('finfixed:cdprice:invalidInputs','Incorrect number of inputs.');

else
    Price = varargin{1};
    Strike = varargin{2};
    Maturity = varargin{3};
    Volatility = varargin{4};
    Interest = varargin{5};
    Dividend = varargin{6};
    y=varargin{7};
end



%-----------------Model parameters------------------------
k_v=1.5; 
v_bar=0.02;
sigma_v=0.15;
k_r=0.3;
r_bar=0.04;
sigma_r=0.1;
rho12=0.1;
rho13=-0;
rho23=0;

%---------------------------------------------------------

%------------Notations used in the formula----------------
S=Price;
K=Strike;
t=Maturity;
r=Interest;
v=Volatility;
b1=sigma_v/2;
av=(k_v*(v_bar-v^2)-b1^2)/2/v;
av1=-(k_v*v_bar-b1^2)/2/v^2-k_v/2;
av2=(k_v*v_bar-b1^2)/v^3;
q1=rho12;
q2=rho13;
q3=rho23;
d=Dividend;
f=r-d;
q=f;
ar=k_r*(r_bar-r);
ar1=-k_r;
br=sigma_r*sqrt(r);
br1=sigma_r/sqrt(r)/2;
br2=-(1/4)*sigma_r/r^(3/2);
%--------------------------------------------------------



z=log(K/S)/v/sqrt(t); %z stands for theta in the paper    
N=(1+erf(z/sqrt(2)))/2; %Standard normal cdf
n=exp(-z^2/2)/sqrt(2*pi);%Standard normal pdf


N0=(1+erf(y/sqrt(2)))/2;
n0=exp(-y^2/2)/sqrt(2*pi);


%Coefficients and their derivatives
C1=K*y*v/(N0*y+n0);
VC1=K*y/(N0*y+n0);
C2=1/2*(-N0*C1*v^2+2*N0*C1*f-n0*y*b1*q1*C1-K*y^2*v^3)/(v*(N0*y^2+N0+n0*y));
VC2=-(N0*C1+K*y^2*v)/(N0*y^2+N0+n0*y);
RC2=N0*C1/(v*(N0*y^2+N0+n0*y));
VVC2=-(N0*C1+K*y^2*v)/(v*(N0*y^2+N0+n0*y));
C3=1/24*(-3*n0*C1*v^4+48*N0*y*b1*q1*VC2*v^2+48*n0*b1*q1*VC2*v^2+24*n0*r*C1*v^2-4*n0*b1^2*y^2*C1-24*N0*y*C2*v^3+24*N0*y*r*C1*v^2-3*n0*b1^2*q1^2*C1*y^4+6*n0*b1*y^2*q1*C1*v^2-24*n0*C2*v^3-96*N0*y*b1*q1*C2*v-72*n0*b1*q1*C2*v-12*n0*av*v*C1-12*n0*b1*y^2*q1*C1*f+48*N0*y*C2*v*f+12*n0*b1*q1*C1*f+48*N0*y*br*q2*v^2*RC2+48*n0*br*q2*v^2*RC2-12*n0*C1*f^2-12*n0*br*q2*v*C1+12*n0*C1*v^2*f+48*n0*C2*v*f-2*n0*b1^2*C1+6*n0*b1*q1*C1*v^2-n0*b1^2*q1^2*C1+10*n0*b1^2*y^2*q1^2*C1+4*K*y^3*v^5)/(v^2*(N0*y^3+3*N0*y+n0*y^2+2*n0));
VC3=1/24*(-12*n0*av1*v^2*C1-9*n0*C1*v^4-96*N0*y*b1*q1*VC2*v^2-72*n0*b1*q1*VC2*v^2+24*n0*r*C1*v^2+4*n0*b1^2*y^2*C1-24*N0*y*C2*v^3+24*N0*y*r*C1*v^2+3*n0*b1^2*q1^2*C1*y^4+6*n0*b1*y^2*q1*C1*v^2-24*n0*C2*v^3+96*N0*y*b1*q1*C2*v+72*n0*b1*q1*C2*v+12*n0*b1*y^2*q1*C1*f-48*N0*y*C2*v*f-12*n0*b1*q1*C1*f+48*n0*VC2*v^2*f+12*n0*C1*f^2+12*n0*C1*v^2*f-48*n0*C2*v*f+48*N0*y*VC2*v^2*f-24*n0*VC2*v^4-24*N0*y*VC2*v^4+2*n0*b1^2*C1+6*n0*b1*q1*C1*v^2+n0*b1^2*q1^2*C1-10*n0*b1^2*y^2*q1^2*C1+48*N0*y*b1*q1*VVC2*v^3+48*n0*b1*q1*VVC2*v^3+12*K*y^3*v^5)/(v^3*(N0*y^3+3*N0*y+n0*y^2+2*n0));
RC3=-1/2*(-4*n0*br1*q2*v^2*RC2+8*N0*y*b1*q1*RC2*v+6*n0*b1*q1*RC2*v-4*n0*C2*v+2*n0*C1*f-4*N0*y*C2*v-4*N0*y*RC2*v*f-2*N0*y*C1*v^2-4*N0*y*br1*q2*v^2*RC2+n0*br1*q2*v*C1-n0*b1*q1*C1-3*n0*C1*v^2+2*n0*RC2*v^3+n0*b1*y^2*q1*C1+2*N0*y*RC2*v^3-4*n0*RC2*v*f)/(v^2*(N0*y^3+3*N0*y+n0*y^2+2*n0));
VVC3=1/12*(-9*n0*C1*v^4+96*N0*y*b1*q1*VC2*v^2+72*n0*b1*q1*VC2*v^2-12*n0*VVC2*v^5-4*n0*b1^2*y^2*C1-3*n0*b1^2*q1^2*C1*y^4-96*N0*y*b1*q1*C2*v-72*n0*b1*q1*C2*v-12*n0*b1*y^2*q1*C1*f+48*N0*y*C2*v*f+12*n0*b1*q1*C1*f+24*N0*y*VVC2*v^3*f-12*N0*y*VVC2*v^5-6*n0*av2*v^3*C1+24*n0*VVC2*v^3*f-48*n0*VC2*v^2*f-12*n0*C1*f^2+48*n0*C2*v*f-48*N0*y*VC2*v^2*f-24*n0*VC2*v^4-24*N0*y*VC2*v^4-2*n0*b1^2*C1-n0*b1^2*q1^2*C1+10*n0*b1^2*y^2*q1^2*C1-48*N0*y*b1*q1*VVC2*v^3-36*n0*b1*q1*VVC2*v^3+12*K*y^3*v^5)/(v^4*(N0*y^3+3*N0*y+n0*y^2+2*n0));
VRC3=-1/2*(2*N0*y*RC2*v^3-8*N0*y*b1*q1*RC2*v-6*n0*b1*q1*RC2*v+4*N0*y*C2*v+4*N0*y*RC2*v*f-4*n0*VC2*v^2-3*n0*C1*v^2+4*n0*RC2*v*f-n0*b1*y^2*q1*C1+4*n0*C2*v+n0*b1*q1*C1-2*N0*y*C1*v^2-4*N0*y*VC2*v^2-2*n0*C1*f+2*n0*RC2*v^3)/(v^3*(N0*y^3+3*N0*y+n0*y^2+2*n0));
RRC3=1/2*(-2*n0*C1+8*N0*y*RC2*v+4*N0*y*br2*q2*v^2*RC2-n0*br2*q2*v*C1+4*n0*br2*q2*v^2*RC2+8*n0*RC2*v)/(v^2*(N0*y^3+3*N0*y+n0*y^2+2*n0));
C4=-1/48*(6*n0*y^5*b1^2*q1^2*C1*f+12*N0*C2*v^5+2*K*y^4*v^7+12*n0*y*b1*q1*C1*v^2*f-36*n0*y*b1*q1*C1*f^2+24*n0*y*br*q2*v*C1*f+96*N0*br*q2*v^2*RC2*f-144*N0*y^2*v^2*C3*f+42*n0*y*b1^2*q1^2*C1*f-10*n0*y*b1^2*C1*v^2-13*n0*y^5*b1^3*q1^3*C1-12*n0*y*C1*v^2*f^2+6*n0*y*C1*v^4*f-44*n0*y^3*b1^2*q1^2*C1*f+24*n0*y*av*v*C1*f+48*N0*ar*v^3*RC2-24*N0*ar*v^2*C1+8*n0*y*C1*f^3+72*N0*C3*v^4-28*n0*y*b1*q1*br*q2*v*C1+24*N0*br*q2*v^3*C1+12*n0*y^3*b1*q1*br*q2*v*C1-12*n0*y*br*q2*v^3*C1+48*N0*br*q2*v^2*C2+48*N0*br*q2^2*v^3*br1*RC2-48*n0*y*b1*q1*br*q2*v^2*RC2-48*N0*br*q2*v^4*RC2-144*N0*b1*q1*br*q2*v^2*RC2-144*N0*br*q2*v^3*RC3-144*N0*y^2*v^3*br*q2*RC3-144*n0*y*br*q2*v^3*RC3+8*n0*y*br*q2^2*v^2*br1*C1-144*N0*b1*q1*VC3*v^3-144*N0*y^2*v^3*b1*q1*VC3-144*n0*y*b1*q1*VC3*v^3+48*N0*C2*v*f^2-48*N0*C2*v^3*f-144*N0*C3*v^2*f+2*n0*y*b1^3*q1*C1-18*n0*y^3*b1^3*q1*C1-12*n0*y^3*b1*q1*C1*v^2*f+48*N0*r*C1*v^2*f-12*n0*y*b1^2*C1*f+8*n0*y*b1*q1*v^2*av1*C1+432*N0*y^2*v^2*b1*q1*C3+288*N0*b1*q1*C3*v^2+432*n0*y*b1*q1*C3*v^2+48*n0*y*ar*v^3*RC2+48*N0*y^2*v^3*ar*RC2+12*n0*y^3*b1*q1*C1*f^2+96*N0*b1*q1*VC2*v^2*f+8*n0*y^3*b1^2*C1*f-24*N0*r*C1*v^4+12*N0*b1^2*C1*v^2-n0*y*C1*v^6-48*N0*C2*v^3*r+72*N0*b1^2*C2*v-48*N0*av*v^2*C2+24*N0*av*v^3*C1+48*N0*av*v^3*VC2+24*n0*y*b1^2*VVC2*v^3-96*n0*y*b1^2*VC2*v^2+33*n0*y^3*b1^3*q1^3*C1+10*n0*y^3*b1^2*q1^2*C1*v^2+48*N0*b1^2*q1^2*v^3*VVC2-96*n0*y*av*v^2*C2-12*n0*y*av*v^3*C1-12*n0*y*b1*q1*av*v*C1+48*n0*y*av*v^3*VC2+12*n0*y^3*b1*q1*av*v*C1+48*N0*y^2*v^3*av*VC2-96*N0*y^2*v^2*av*C2-12*n0*y^3*b1^2*q1^2*C2*v-48*n0*y*C2*v^3*r-9*n0*y*b1^3*q1^3*C1-n0*y*b1^2*q1^2*C1*v^2+3*n0*y*b1*q1*C1*v^4-24*n0*y*b1*q1*v^2*r*C1-192*N0*b1*q1*C2*v*f-48*n0*y*b1*q1*C2*v*f-144*n0*y*C3*v^2*f-144*N0*b1^2*q1^2*VC2*v^2+24*N0*b1^2*VVC2*v^3-48*N0*b1^2*VC2*v^2-3*n0*y^5*b1^2*q1^2*C1*v^2+n0*y^7*b1^3*q1^3*C1-4*n0*y^3*b1^2*C1*v^2+4*n0*y^5*b1^3*q1*C1+3*n0*y^3*b1*q1*C1*v^4+24*N0*y^2*v^3*b1^2*VVC2-96*N0*y^2*v^2*b1^2*VC2-48*N0*b1*q1*VC2*v^4-48*n0*y*b1^2*q1^2*VC2*v^2+128*n0*y*b1^2*C2*v-48*N0*y^2*v^3*C2*r+144*N0*y^2*v*b1^2*C2+24*n0*y*b1*q1*C2*v^3+100*n0*y*b1^2*q1^2*C2*v+72*n0*y*C3*v^4+48*N0*b1*q1*C2*v^3+192*N0*b1^2*q1^2*C2*v+72*N0*y^2*v^4*C3)/(v^3*(3*N0+N0*y^4+6*N0*y^2+5*n0*y+n0*y^3));
RC4=1/24*(72*N0*y^2*v^3*b1*q1*VRC3+72*n0*y*b1*q1*VRC3*v^3+6*n0*y*b1^2*C1-12*n0*y*br*q2*v*C1+6*n0*y^3*b1*q1*C1*v^2-3*n0*y^5*b1^2*q1^2*C1-144*N0*b1*q1*RC3*v^2-3*n0*y*C1*v^4-48*N0*b1*q1*VC2*v^2-216*n0*y*b1*q1*RC3*v^2-50*n0*y*b1^2*q1^2*RC2*v-24*N0*b1*q1*RC2*v^3-72*N0*y^2*v*b1^2*RC2-12*n0*y*b1*q1*RC2*v^3+24*n0*y*RC2*v^3*r+6*n0*y^3*b1^2*q1^2*RC2*v+24*N0*y^2*v^3*RC2*r+48*N0*y^2*v^2*av*RC2+12*n0*y*C1*v^2*f-12*n0*y^3*b1*q1*C1*f+72*n0*y*RC3*v^2*f-72*N0*br*q2*v^2*RC2+22*n0*y^3*b1^2*q1^2*C1+12*N0*C1*v^4+96*N0*b1*q1*C2*v-12*n0*y*av*v*C1-24*N0*r*C1*v^2-96*N0*b1^2*q1^2*RC2*v+24*N0*av*v^2*RC2+72*N0*y^2*v^2*RC3*f+24*n0*y*b1*q1*RC2*v*f+96*N0*b1*q1*RC2*v*f-12*n0*y*br1*q2*v*C1*f-48*N0*br1*q2*v^2*RC2*f+36*n0*y*b1*q1*C1*f-12*n0*y*C1*f^2+48*n0*y*av*v^2*RC2+12*N0*ar1*v^2*C1+72*N0*y^2*v^3*br1*q2*RC3+72*n0*y*br1*q2*v^3*RC3+24*n0*y*b1*q1*C2*v-4*n0*y^3*b1^2*C1+72*N0*y^2*v^2*C3-21*n0*y*b1^2*q1^2*C1+72*n0*y*C3*v^2-6*N0*RC2*v^5-12*N0*br1*q2*v^3*C1-4*n0*y*br1^2*q2^2*v^2*C1+72*N0*br1*q2*v^3*RC3+24*N0*br1*q2*v^4*RC2+72*N0*b1*q1*br1*q2*v^2*RC2-216*N0*y^2*v^2*b1*q1*RC3-36*N0*y^2*v^4*RC3-36*n0*y*RC3*v^4-48*N0*C2*v*f-24*N0*RC2*v*f^2+24*N0*RC2*v^3*f+72*N0*RC3*v^2*f+6*n0*y*b1*q1*C1*v^2-24*N0*y^2*v^3*ar1*RC2-24*n0*y*ar1*v^3*RC2+14*n0*y*b1*q1*br1*q2*v*C1-24*N0*br1*q2*v^2*C2+6*n0*y*br1*q2*v^3*C1-6*n0*y^3*b1*q1*br1*q2*v*C1+24*n0*y*b1*q1*br1*q2*v^2*RC2-24*N0*br1^2*q2^2*v^3*RC2+72*N0*b1*q1*VRC3*v^3-36*N0*RC3*v^4-24*N0*ar1*v^3*RC2-64*n0*y*b1^2*RC2*v+72*N0*y^2*v^3*br*q2*RRC3+24*N0*y^2*v^3*C2-24*N0*C1*v^2*f+24*n0*y*C2*v^3-4*n0*y*br*q2^2*v^2*br2*C1-24*N0*br*q2^2*v^3*br2*RC2+72*n0*y*br*q2*v^3*RRC3+72*N0*br*q2*v^3*RRC3+48*N0*C2*v^3+72*N0*C3*v^2-36*N0*b1^2*RC2*v+24*N0*RC2*v^3*r)/(v^3*(N0*y^4+6*N0*y^2+3*N0+5*n0*y+n0*y^3));
VC4=1/24*(-12*n0*y^3*b1^2*q1^2*C2*v-216*n0*y*b1*q1*VC3*v^3-72*N0*C3*v^2*f+8*n0*y*C1*f^3-24*N0*VC2*v^2*f^2+24*N0*VC2*v^4*f+72*N0*VC3*v^3*f-48*N0*b1*q1*VVC2*v^3*f+72*n0*y*VC3*v^3*f-74*n0*y*b1^2*q1^2*VC2*v^2-60*N0*b1^2*VC2*v^2+6*n0*y^3*b1*q1*br*q2*v*C1-24*n0*y*b1*q1*br*q2*v^2*RC2+24*N0*br*q2*v^2*C2-192*N0*b1*q1*C2*v*f+12*n0*y*av*v*C1*f-48*n0*y*b1*q1*C2*v*f+8*n0*y^3*b1^2*C1*f-72*N0*y^2*v^2*C3*f-36*n0*y*b1*q1*C1*f^2+42*n0*y*b1^2*q1^2*C1*f-72*n0*y*C3*v^2*f-36*N0*VC3*v^5-48*N0*y^2*v^2*av*C2+48*n0*y*av*v^3*VC2-12*N0*C2*v^5-18*n0*y^3*b1^3*q1*C1+6*n0*y*av*v^3*C1+6*n0*y^3*b1*q1*av*v*C1+144*N0*y^2*v*b1^2*C2-144*N0*b1*q1*VC3*v^3-13*n0*y^5*b1^3*q1^3*C1+33*n0*y^3*b1^3*q1^3*C1+144*N0*b1*q1*VC2*v^2*f+n0*y^7*b1^3*q1^3*C1+4*n0*y^5*b1^3*q1*C1-6*n0*y*b1*q1*av*v*C1-12*n0*y*b1^2*C1*f+12*n0*y*br*q2*v*C1*f+24*N0*VC2*v^4*r-12*N0*av1*v^4*C1-36*n0*y*VC3*v^5-36*N0*y^2*v^5*VC3-24*N0*av1*v^4*VC2+24*N0*av1*v^3*C2-24*N0*y^2*v^4*av*VVC2-24*n0*y*av*v^4*VVC2-36*n0*y*C3*v^4+100*n0*y*b1^2*q1^2*C2*v+72*N0*b1^2*C2*v+72*N0*br*q2*v^4*VRC3+24*n0*y*b1^2*q1^2*VVC2*v^3+72*n0*y*b1*q1*VVC3*v^4+24*N0*b1*q1*VVC2*v^5+24*n0*y*VC2*v^4*r+24*N0*y^2*v^4*VC2*r-4*n0*y*b1*q1*v^3*av2*C1+6*n0*y^3*b1^2*q1^2*VC2*v^2-12*n0*y*b1*q1*VC2*v^4+48*n0*y*av1*v^3*C2+48*N0*y^2*v^3*av1*C2-6*n0*y^3*b1*q1*av1*v^2*C1+72*N0*b1*q1*VVC3*v^4+2*n0*y*b1^3*q1*C1+72*N0*b1^2*q1^2*v^3*VVC2+6*n0*y*b1*q1*v^2*av1*C1+216*n0*y*b1*q1*C3*v^2-36*N0*y^2*v^4*C3+6*n0*y*av1*v^4*C1-24*n0*y*av1*v^4*VC2-24*N0*br*q2*v^3*VC2+144*N0*b1*q1*C3*v^2+216*N0*y^2*v^2*b1*q1*C3-168*N0*b1^2*q1^2*VC2*v^2-48*n0*y*av*v^2*C2+24*N0*av*v^3*VC2-24*N0*av*v^2*C2-4*K*y^4*v^7+24*N0*r*C1*v^4-36*N0*C3*v^4+24*N0*b1^2*VVC2*v^3+2*n0*y*C1*v^6+192*N0*b1^2*q1^2*C2*v+128*n0*y*b1^2*C2*v-12*N0*av*v^3*C1+48*N0*y^2*v^3*av*VC2-112*n0*y*b1^2*VC2*v^2-120*N0*y^2*v^2*b1^2*VC2+24*n0*y*b1*q1*VC2*v^2*f+72*N0*y^2*v^3*VC3*f-12*n0*y*av1*v^2*C1*f-3*n0*y^3*b1*q1*C1*v^4+6*n0*y*br*q2*v^3*C1-72*N0*b1*q1*br*q2*v^2*RC2-12*N0*br*q2*v^3*C1+6*n0*y^5*b1^2*q1^2*C1*f-6*n0*y*C1*v^4*f+12*n0*y^3*b1*q1*C1*f^2+48*N0*br*q2*v^2*RC2*f-44*n0*y^3*b1^2*q1^2*C1*f-216*N0*y^2*v^3*b1*q1*VC3+24*N0*br*q2*v^4*RC2-24*N0*y^2*v^4*av1*VC2+48*n0*y*b1^2*VVC2*v^3-6*N0*VC2*v^6+72*N0*y^2*v^4*b1*q1*VVC3+72*N0*y^2*v^4*br*q2*VRC3+72*n0*y*br*q2*v^4*VRC3+48*N0*C2*v*f^2-24*N0*av*v^4*VVC2-14*n0*y*b1*q1*br*q2*v*C1-3*n0*y*b1*q1*C1*v^4-9*n0*y*b1^3*q1^3*C1+48*N0*y^2*v^3*b1^2*VVC2)/(v^4*(N0*y^4+6*N0*y^2+3*N0+5*n0*y+n0*y^3));
C5=1/5760*(-5760*N0*y^3*v^4*q3*br*b1*VRC3+86400*N0*y*b1*q1*v^3*br*q2*RC3-17280*n0*br*q2*v^3*C3-360*n0*y^2*v^5*br*q2*C1+16320*n0*br*q2*v^2*b1^2*RC2-11520*N0*y*br*q2*v^4*RC2*r+5760*N0*y*q3*br*b1*v^3*VC2-2880*n0*v^5*br*q2^2*br1*RC2-17280*n0*br^2*q2^2*v^4*RRC3-960*n0*br*q2*v^3*ar1*C1+1440*n0*y^2*br*q2*v*b1^2*C1-13440*n0*y^2*b1^2*q1^2*br*q2*v^2*RC2+720*n0*y^2*b1^2*q1*q3*br*v*C1-11520*n0*br*q2*v^4*RC2*r+23040*N0*y*br*q2*v^2*b1^2*RC2+1920*n0*y^2*br*q2*v^2*b1^2*RC2-240*n0*y^2*br^2*q2^3*v^3*br2*C1+1920*n0*br^2*q2^3*v^4*br2*RC2+23040*N0*y^3*v^4*br*q2*RC4+69120*N0*y*br*q2*v^4*RC4-1080*n0*v^5*br*q2*C1+1440*n0*b1*q1*ar*v^2*C1-120*n0*v^2*b1^2*q1^2*C1*f+240*n0*b1^3*q1*C1*f-17280*N0*y*v^2*C3*f^2+2160*n0*y^2*b1^2*C1*f^2+5760*n0*b1*q1*VC2*v^2*f^2-120*n0*b1^4*q1^2*y^8*C1-15*n0*y^2*v^8*C1-840*n0*b1^3*y^4*v^2*q1*C1+390*n0*b1^2*y^4*v^4*q1^2*C1-3771*n0*y^2*b1^4*q1^4*C1-1440*n0*y^2*v^4*b1*q1*r*C1+2400*n0*b1^3*y^4*v^2*q1^3*C1-177*n0*b1^4*q1^4*C1+5760*N0*y*v^3*b1^2*VVC2*f-6720*n0*y^2*b1^3*q1*C1*f-11760*n0*b1^3*y^4*q1^3*C1*f+12960*n0*y^2*b1^3*q1^3*C1*f+240*n0*C1*f^4+150*n0*v^4*b1^2*q1^2*C1+60*n0*b1^3*q1^3*y^8*v^2*C1+17280*n0*b1^2*VC3*v^3-480*n0*b1*y^4*q1*C1*f^3+5760*n0*v^3*b1^2*VVC2*f-23040*N0*y*v^2*av*C2*f-34560*n0*v^3*br*q2*RC3*f-34560*N0*y*v^3*br*q2*RC3*f-960*n0*av*v^3*av1*C1+2880*n0*y^2*b1*q1*v^2*av*C2-720*n0*v^5*b1*q1*C2-11520*n0*av*v^4*VC3-5760*n0*v^5*av*VC2+2880*n0*v^4*av*C2-1080*n0*v^5*av*C1+17280*n0*av*v^3*C3-240*n0*y^2*C1*f^4+1920*n0*C2*v*f^3+17280*n0*v^4*C3*f-17280*n0*v^2*C3*f^2+2880*n0*y^2*b1*q1*C1*f^3+360*n0*v^4*b1*q1*C1*f+360*n0*b1^2*y^6*v^2*q1^2*C1*f-240*n0*y^2*b1^2*C1*v^2*f-23040*N0*y*b1*q1*v^3*ar*RC2+1440*n0*v^3*br*q2*C1*f-1440*n0*y^2*av*v*C1*f^2-1440*n0*b1*y^4*q1*av*v*C1*f-23040*n0*b1*q1*br*q2*v^2*RC2*f+5760*n0*y^2*b1*q1*br*q2*v^2*RC2*f+7680*n0*y^2*b1*q1*br*q2*v*C1*f+24000*n0*v*b1^2*C2*f-120*n0*b1^3*q1^3*y^8*C1*f-7200*n0*v^3*b1^2*C2-14400*n0*b1*q1*C2*v*f^2-11520*N0*y*v^3*C2*r*f-3360*n0*b1*q1*br*q2*v*C1*f-960*n0*y^2*v^3*b1*q1*br*q2*C1-17280*N0*y*br*q2*v^3*C3-11520*n0*q3*br*b1*VRC3*v^4+5760*n0*b1*q1*br*q2*v^3*VC2+1900*n0*b1^4*y^6*q1^2*C1-3530*n0*b1^4*y^6*q1^4*C1-840*n0*b1^3*y^6*v^2*q1^3*C1+435*n0*b1^4*q1^4*y^8*C1+960*n0*b1*q1*v^2*av1*C1*f-960*n0*y^2*b1*q1*v^2*av1*C1*f+120*n0*y^2*v^6*C1*f-360*n0*y^2*v^4*C1*f^2-207360*N0*y*b1*q1*C4*v^3-960*n0*ar*v^3*br1*q2*C1+720*n0*b1*y^4*v^3*q1*br*q2*C1+2880*n0*v^3*br*q2*C1*r-480*n0*b1^2*y^4*br*q2*v*C1+480*n0*y^2*v^4*br*q2^2*br1*C1+240*n0*br*q2^3*v^3*br1^2*C1+1920*n0*br*q2^2*v^3*br1*C2-360*n0*b1^2*y^6*q1^2*br*q2*v*C1+240*n0*br^2*q2^3*v^3*br2*C1-5760*n0*y^2*v^4*q3*br*b1*VRC3-360*n0*b1*y^4*v^4*q1*C1*f+5760*n0*y^2*b1*q1*av*v*C1*f-2880*n0*ar*v^2*C1*f-1440*n0*b1*y^4*q1*br*q2*v*C1*f+15*n0*v^8*C1-5760*n0*v^4*br*q2*RC2*f-1440*n0*y^2*br*q2*v*C1*f^2+5760*n0*y^2*v^4*C3*r+720*n0*v^2*b1*q1*C1*f^2-17280*n0*v^2*av*C2*f-1440*n0*b1*q1*av*v*C1*f+11520*n0*v^3*av*VC2*f+1440*n0*y^2*av*v^3*C1*f-240*n0*v^7*C2-5760*N0*y^3*v^4*av*VC3+480*n0*av*v*b1^2*C1-360*n0*b1^2*y^6*q1^2*av*v*C1+11520*N0*y*b1*q1*v^4*av*VVC2+2880*n0*av*v^3*r*C1+720*n0*v^3*b1*q1*av*C1+5760*N0*y*ar*v^4*br1*q2*RC2+480*n0*b1^2*y^4*v^2*C1*f-480*n0*b1^3*y^6*q1*C1*f-120*n0*v^6*C1*f-23040*n0*v^5*C4-4320*n0*v^6*C3+60*n0*b1*y^4*v^6*q1*C1-2880*N0*y^3*v^4*b1^2*VVC3+240*n0*b1^3*y^6*v^2*q1*C1-90*n0*b1^2*y^6*v^4*q1^2*C1-15*n0*b1^4*q1^4*C1*y^10-2880*n0*r^2*v^4*C1+720*n0*v^6*r*C1+1440*n0*br*q2*v*C1*f^2-5760*n0*q3*br*b1*v^2*RC2*f+5760*n0*br*q2*v^2*RC2*f^2+720*n0*b1*y^4*q1*C1*v^2*f^2-92160*N0*y^3*v^3*b1*q1*C4-23040*N0*y*v^2*b1^2*VC2*f+69120*N0*y*C4*v^3*f+23040*n0*y^2*v^3*C4*f-11520*n0*v^3*C2*r*f-16320*n0*y^2*b1^2*q1^2*C2*v*f-720*n0*b1^2*C1*f^2+1440*n0*C2*v^5*f-2880*n0*v^3*C2*f^2+360*n0*v^4*C1*f^2-480*n0*C1*v^2*f^3+46080*n0*C4*v^3*f-480*n0*b1^2*y^4*C1*f^2+2520*n0*b1^2*q1^2*C1*f^2+240*n0*b1^2*q1^2*v^3*av2*C1-4320*n0*y^2*b1^2*q1^2*v^2*C3-720*n0*b1^2*q1*q3*br*v*C1-17280*N0*y*br*q2*v^3*av*RC2-2880*n0*q3*br*b1*v^4*RC2+5760*N0*y*br^2*v^3*RC2-17280*N0*y*q3*br*b1*VRC3*v^4+5760*n0*q3*br*b1*v^3*VC2+2880*n0*y^2*b1*q1*br*q2*v^2*C2-12480*n0*b1*q1*br*q2*v^2*C2+2880*n0*y^2*b1*q1*br*q2^2*v^3*br1*RC2-17280*N0*y*br^2*q2^2*v^4*RRC3+5760*N0*y*br*q2*v^4*ar1*RC2-2880*N0*y*q3*br*b1*v^4*RC2+11520*N0*y*q3*br*b1^2*v^2*q1*RC2+1320*n0*b1^2*q1^2*br*q2*v*C1+48*K*y^5*v^9-120*n0*b1^2*y^4*v^4*C1+17280*n0*v^5*b1*q1*VC3+5760*N0*y^3*v^4*C3*r+11520*N0*y*v^3*ar*RC2*f+4440*n0*b1^2*y^4*q1^2*C1*f^2-34560*N0*y*v^3*b1*q1*VC3*f-1080*n0*b1^3*q1^3*C1*f+34560*N0*y*v*b1^2*C2*f-28800*N0*y*b1^3*q1*v^3*VVC2-8640*n0*b1^3*q1^3*v^3*VVC2+5760*n0*y^2*b1^2*q1^2*VC2*v^2*f+23040*N0*y^3*v^3*C4*f+86400*n0*v^2*b1*q1*C3*f+1440*n0*y^2*v^3*br*q2*C1*f-2400*n0*y^2*v^2*b1^2*q1^2*C1*r-720*n0*y^2*av^2*v^2*C1-120*n0*b1^2*q1^2*av*v*C1+720*n0*y^2*v^5*b1*q1*C2+240*n0*b1^3*y^6*q1^3*C2*v+17280*N0*y*v^4*C3*r-155520*N0*y*b1^2*q1^2*v^2*C3-8640*N0*y*b1^2*VVC3*v^4+23040*n0*y^2*v^4*b1*q1*VC4+720*n0*y^2*v^4*b1*q1*C1*f+2880*n0*y^2*v^2*b1*q1*C1*r*f-2880*n0*y^2*v^2*b1*q1*C1*f^2+3720*n0*y^2*v^2*b1^2*q1^2*C1*f-420*n0*y^2*v^4*b1^2*C1+2880*n0*y^2*b1^3*q1^3*v^3*VVC2-360*n0*b1^2*y^6*q1^2*C1*f^2+11520*N0*y*v^3*av*VC2*f+1440*n0*b1^2*y^4*q1^2*C2*v*f+8640*n0*v^3*b1*q1*C2*f-34560*N0*y*v^4*b1*q1*C3-60480*N0*y*b1^2*v^2*C3-25920*n0*v^4*b1*q1*C3+1440*n0*v^6*b1*q1*VC2-2880*n0*y^2*v^3*b1*q1*C2*f+5760*n0*br*q2*v^2*C2*f+1920*n0*y^2*v*b1^2*C2*f-5760*N0*y*v^5*ar*RC2+5760*n0*ar*v^3*C2+480*n0*b1^2*v^2*r*C1-900*n0*v^4*b1^2*C1-13440*n0*y^2*b1^3*q1^3*VC2*v^2+5760*n0*b1^2*q1^2*v^3*VVC2*f-2880*n0*v^4*r*C1*f-180*n0*v^6*b1*q1*C1-840*n0*y^2*v^2*b1^3*q1^3*C1-5760*N0*y*v^5*av*VC2-17280*N0*y*b1^2*q1^2*v^4*VVC3-17280*N0*y*av*v^4*VC3+960*n0*y^2*av*v*b1^2*C1+34560*N0*y*av*v^3*C3-480*n0*b1^2*y^4*av*v*C1+11520*n0*b1*q1*v^4*av*VVC2-11520*n0*b1*q1*v^4*VC2*r+5760*N0*y*v^4*b1^2*VC2-17280*n0*b1^2*q1^2*v^4*VVC3-92160*n0*y^2*v^3*b1*q1*C4-115200*n0*b1*q1*C4*v^3+2880*n0*C1*v^2*r*f^2+480*n0*y^2*C1*v^2*f^3+5760*N0*y*v^5*C2*r-5760*N0*y*q3*br*b1*v^2*RC2*f+5760*n0*br*q2^2*v^3*br1*RC2*f-34560*n0*v^3*b1*q1*VC3*f-10440*n0*y^2*b1^2*q1^2*C1*f^2+1440*n0*v^3*av*C1*f+86400*N0*y*b1^2*q1^2*v^3*VC3-17280*n0*b1*q1*v^3*ar*RC2-2880*N0*y*v^5*b1^2*VVC2-2880*n0*v^5*b1^2*q1^2*VVC2+103680*N0*y*v^2*b1*q1*C3*f+17280*N0*y*v^4*C3*f-2880*n0*b1*q1*v^2*r*C1*f+23040*N0*y^3*v^4*b1*q1*VC4+2880*n0*y^2*b1*q1*C2*v*f^2+35040*n0*b1^2*q1^2*C2*v*f-5760*n0*v^4*b1*q1*VC2*f-23040*n0*b1^2*q1^2*VC2*v^2*f+1920*n0*q3*br*b1*v*C1*f+30*n0*y^2*v^4*b1^2*q1^2*C1-120*n0*v^2*b1^3*q1*C1+17280*N0*y^3*v^3*b1^2*VC3+17280*N0*y*v^5*b1*q1*VC3+17280*n0*y^2*v^3*b1^2*VC3-1440*n0*v^4*b1*q1*r*C1-252*n0*b1^4*C1-276*n0*y^2*b1^4*C1+69120*N0*y*b1*q1*VC4*v^4+5760*N0*y*b1*q1*v^4*av1*VC2-480*n0*b1^2*y^4*q1^2*v^2*av1*C1-240*n0*b1^2*q1^2*v^2*av1*C1-103680*N0*y*b1^3*q1*v*C2+46080*n0*b1*q1*VC4*v^4+5760*n0*br*q2*v^4*ar1*RC2+46080*n0*br*q2*v^4*RC4-2880*N0*y^3*v^4*br^2*RRC3+34560*N0*y*b1^2*VC3*v^3-80*n0*b1^4*y^6*C1+5760*n0*v^5*C2*r-34560*N0*y^3*v^2*b1^2*C3-4320*N0*y*v^6*C3+240*n0*v^2*b1^2*q1^2*C1*r+5280*n0*y^2*v^3*b1^2*q1^2*C2+960*n0*b1^3*y^4*q1*v*C2-27600*n0*b1^3*q1^3*C2*v+17280*n0*b1*q1*v^3*C2*r+23040*N0*y*b1*q1*v^3*C2*r+22320*n0*y^2*b1^3*q1^3*C2*v-8640*N0*y*v^3*b1^2*C2+4800*n0*y^2*b1^3*q1*v^2*VC2-11520*N0*y*b1*q1*v^4*VC2*r+80640*N0*y*b1^3*q1*v^2*VC2-1440*n0*b1*q1*C1*f^3+240*n0*b1^2*C1*v^2*f-3000*n0*b1^2*y^4*v^2*q1^2*C1*f+2400*n0*b1^3*y^6*q1^3*C1*f+564*n0*b1^4*q1^2*C1+2652*n0*y^2*b1^4*q1^2*C1+2880*n0*v^4*b1^2*VC2-5760*n0*b1^2*VVC3*v^4-34560*n0*y^2*v^2*b1^2*C3+576*n0*b1^4*y^4*C1+1440*n0*b1^3*y^4*q1^3*VC2*v^2-60*n0*v^2*b1^3*q1^3*C1+960*n0*y^2*b1^2*v^2*r*C1-6372*n0*b1^4*y^4*q1^2*C1+5760*n0*v^4*b1^2*q1^2*VC2-2880*n0*y^2*v^4*b1^2*q1^2*VC2+53760*n0*b1^3*q1*v^2*VC2+22560*n0*b1^3*q1^3*VC2*v^2-360*n0*y^2*v^5*av*C1+720*n0*b1*y^4*v^3*q1*av*C1-5760*n0*y^2*v^4*ar*RC3-1440*n0*y^2*b1*q1*ar*v^2*C1+5760*N0*y*ar*v^3*C2-11520*n0*ar*v^4*RC3+4320*n0*ar*v^4*C1-5760*n0*v^5*ar*RC2-7800*n0*y^2*b1^2*q1^2*br*q2*v*C1+2880*n0*br^2*v^4*br2*q2*RC2-480*n0*br^2*v^3*br2*q2*C1+2880*N0*y*br^2*v^4*br2*q2*RC2-480*n0*b1*y^4*q1*br*q2^2*v^2*br1*C1+3960*n0*b1^2*y^4*q1^2*br*q2*v*C1+1440*n0*v^6*br*q2*RC2+22560*n0*b1^2*q1^2*br*q2*v^2*RC2-5760*N0*y*br*q2*v^4*C2+480*n0*v^4*br*q2^2*br1*C1+2160*n0*y^2*b1*q1*br*q2^2*v^2*br1*C1+1920*n0*br*q2^3*v^4*br1^2*RC2-240*n0*y^2*br*q2^3*v^3*br1^2*C1-17280*n0*br*q2^2*v^4*br1*RC3-17280*N0*y*br*q2^2*v^4*br1*RC3-8640*N0*y*br^2*v^4*RRC3-5760*n0*q3*br*b1*v^2*C2-5760*N0*y*q3*br*b1*v^2*C2-40320*N0*y*b1*q1*v^3*av*VC2-240*n0*av^2*v^2*C1+8466*n0*b1^4*y^4*q1^4*C1-110880*n0*b1^2*q1^2*v^2*C3+5760*n0*ar*v^4*br1*q2*RC2-11520*n0*br*q2*v^3*av*RC2+480*n0*br*q2*v^2*av*C1-720*n0*y^2*br^2*q2^2*v^2*C1+720*n0*br^2*q2^2*v^2*C1+2880*N0*y*q3*br*b1*v^3*C1-240*n0*v^3*b1*q1*br*q2*C1-34560*n0*b1*q1*v^4*br*q2*VRC3-34560*N0*y*b1*q1*v^4*br*q2*VRC3-5760*n0*br^2*v^4*RRC3+5760*n0*br^2*v^3*RC2-960*n0*br^2*v^2*C1-720*n0*y^2*b1^2*v^2*av1*C1+480*n0*v^4*b1*q1*av1*C1-9600*n0*b1*q1*v^3*av1*C2+37440*n0*b1*q1*v^2*av*C2+5760*N0*y*v^4*av*C2+17280*n0*y^2*v^3*av*C3-720*n0*b1*q1*br*q2^2*v^2*br1*C1-2880*n0*y^2*v^4*br^2*RRC3-8640*n0*b1*q1*br*q2^2*v^3*br1*RC2-1440*n0*y^2*br*q2*v^2*av*C1+23040*n0*y^2*v^4*br*q2*RC4+69120*n0*b1*q1*v^3*br*q2*RC3+5760*n0*br^2*q2^2*v^3*RC2-8640*n0*br*q2*v^4*C2+5760*n0*v^4*b1*q1*br*q2*RC2+9600*n0*q3*br*b1^2*v^2*q1*RC2+1440*n0*b1^2*y^4*q1^2*br*q2*v^2*RC2+17280*N0*y*v^5*br*q2*RC3+17280*n0*v^5*br*q2*RC3+3840*n0*q3*br*b1*v^3*C1-2880*n0*y^2*v^4*b1*q1*br*q2*RC2-67680*n0*b1^3*q1*v*C2-6960*n0*v^3*b1^2*q1^2*C2-10080*n0*y^2*b1^3*q1*v*C2-4560*n0*b1^3*y^4*q1^3*C2*v+5760*n0*b1*q1*v^4*av1*VC2-960*n0*y^2*v^3*b1^2*C2-2880*n0*y^2*v^4*b1^2*VVC3+960*n0*br*q2^2*v^2*br1*C1*f-960*n0*y^2*br*q2^2*v^2*br1*C1*f+1440*n0*av*v*C1*f^2+4560*n0*b1^3*y^4*q1*C1*f+480*n0*y^2*v^4*b1*q1*av1*C1-240*n0*b1^2*v^2*av1*C1+1680*n0*y^2*b1^2*q1^2*v^2*av1*C1+11520*n0*v^4*C3*r-31680*n0*b1^2*v^2*C3-2880*N0*y*r^2*v^4*C1-11520*N0*y*b1*q1*v^3*av1*C2-240*n0*y^2*b1^2*q1^2*v^3*av2*C1+3000*n0*b1^2*y^4*q1^2*av*v*C1-5760*n0*y^2*v^4*av*VC3+17280*N0*y^3*v^3*av*C3-28800*n0*b1*q1*v^3*av*VC2-3480*n0*y^2*b1^2*q1^2*av*v*C1+57600*N0*y*b1*q1*v^2*av*C2-34560*N0*y*v^5*C4-11520*N0*y^3*v^5*C4-11520*n0*y^2*v^5*C4-17280*n0*v^2*b1^2*VC2*f+11520*n0*v^3*ar*RC2*f-20160*n0*b1^3*q1*v^3*VVC2+69120*n0*b1^2*q1^2*v^3*VC3+720*n0*b1^2*y^4*v^2*q1^2*C1*r-2880*n0*v^5*b1^2*VVC2-5760*N0*y^3*v^4*ar*RC3-17280*N0*y*ar*v^4*RC3+2880*N0*y*ar*v^4*C1-480*n0*b1^2*v^3*av2*C1-720*n0*b1^2*y^4*v^3*q1^2*C2)/(v^4*(15*N0*y+N0*y^5+10*N0*y^3+n0*y^4+9*n0*y^2+8*n0));


%Elements of the formula
Pn1=C1;
PN1=z*C1;
Pn2=1/2*z*(2*C2*v+b1*q1*C1)/v;
PN2=1/2*(2*C2*v*z^2+2*C2*v+C1*v^2-2*C1*f)/v;
Pn3=1/24*(24*C3*v^2*z^2+48*C3*v^2+3*b1^2*q1^2*C1*z^4-6*b1*C1*z^2*q1*v^2-10*b1^2*C1*z^2*q1^2+12*b1*C1*z^2*q1*f+4*b1^2*C1*z^2+12*C1*f^2-12*C1*v^2*f+12*av*v*C1-24*r*C1*v^2+2*b1^2*C1-12*b1*q1*C1*f+12*br*q2*v*C1-48*b1*q1*VC2*v^2+72*b1*q1*C2*v-48*br*q2*v^2*RC2-48*C2*v*f+24*C2*v^3+3*C1*v^4+b1^2*q1^2*C1-6*b1*q1*C1*v^2)/v^2;
PN3=-z*(-C3*v*z^2-3*C3*v+2*br*q2*v*RC2+2*C2*f-4*b1*q1*C2+2*b1*q1*VC2*v+r*C1*v-C2*v^2)/v;
Pn4=1/48*z*(48*ar*v^3*RC2-48*C2*v^3*r+128*b1^2*C2*v+24*b1^2*VVC2*v^3-12*av*v^3*C1-96*av*v^2*C2+48*av*v^3*VC2-144*b1*q1*VC3*v^3+8*b1*q1*v^2*av1*C1-12*br*q2*v^3*C1-144*br*q2*v^3*RC3-28*b1*q1*br*q2*v*C1-C1*v^6+72*C3*v^4+42*b1^2*q1^2*C1*f-36*b1*q1*C1*f^2+24*av*v*C1*f+b1^3*q1^3*C1*z^6-18*b1^3*z^2*q1*C1+33*b1^3*z^2*q1^3*C1-4*b1^2*z^2*C1*v^2+8*b1^2*z^2*C1*f+4*b1^3*q1*C1*z^4-13*b1^3*q1^3*C1*z^4+8*br*q2^2*v^2*br1*C1-48*b1*q1*br*q2*v^2*RC2+24*b1*q1*C2*v^3+432*b1*q1*C3*v^2-48*b1*q1*C2*v*f-12*b1^2*C1*f+6*C1*v^4*f-12*C1*v^2*f^2-144*C3*v^2*f+240*C4*v^3+48*C4*v^3*z^2+8*C1*f^3+12*b1*q1*C1*v^2*f+24*br*q2*v*C1*f-12*b1^2*z^2*q1^2*C2*v+12*b1*z^2*q1*av*v*C1+12*b1*z^2*q1*br*q2*v*C1-12*b1*z^2*q1*C1*v^2*f+12*b1*z^2*q1*C1*f^2+10*b1^2*z^2*q1^2*C1*v^2+3*b1*z^2*q1*C1*v^4-44*b1^2*z^2*q1^2*C1*f+6*b1^2*q1^2*C1*z^4*f-3*b1^2*q1^2*C1*z^4*v^2-96*b1^2*VC2*v^2-12*b1*q1*av*v*C1-10*b1^2*C1*v^2-9*b1^3*q1^3*C1+2*b1^3*q1*C1-b1^2*q1^2*C1*v^2-24*b1*q1*v^2*r*C1+100*b1^2*q1^2*C2*v+3*b1*q1*C1*v^4-48*b1^2*q1^2*VC2*v^2)/v^3;
PN4=1/4*(-4*av*v*C2+4*av*v^2*VC2+4*ar*v^2*RC2+8*br*q2*v*RC2*f+8*b1*q1*VC2*v*f-4*C2*v^2*r+6*z^2*C3*v^3+24*b1*q1*C3*v+6*b1^2*C2+2*b1^2*VVC2*v^2+6*C3*v^3-4*b1^2*VC2*v-12*br*q2*v^2*RC3+2*br*q2*v^2*C1+4*b1*q1*C2*v^2+4*b1^2*q1^2*v^2*VVC2-4*b1*q1*VC2*v^3+4*br*q2*v*C2-4*br*q2*v^3*RC2+16*b1^2*q1^2*C2-12*b1^2*q1^2*VC2*v+4*r*C1*v*f-16*b1*q1*C2*f+4*z^2*ar*v^2*RC2-12*z^2*C3*v*f-8*z^2*av*v*C2-8*z^2*b1^2*VC2*v-12*b1*q1*VC3*v^2+2*z^2*b1^2*VVC2*v^2+12*C4*v^2-4*z^2*C2*v^2*r+4*z^2*av*v^2*VC2-12*C3*v*f-2*r*C1*v^3+2*av*v^2*C1-2*ar*v*C1+C2*v^4+4*C2*f^2-12*z^2*br*q2*v^2*RC3-12*z^2*b1*q1*VC3*v^2+36*z^2*b1*q1*C3*v+4*br*q2^2*v^2*br1*RC2-12*b1*q1*br*q2*v*RC2+b1^2*C1*v-4*C2*v^2*f+12*z^2*b1^2*C2+4*C4*v^2*z^4+24*C4*v^2*z^2)/v^2;
Pn5=1/5760*(-11520*v^4*C3*r+31680*b1^2*v^2*C3+2880*v^5*b1^2*VVC2-17280*v^5*b1*q1*VC3+67680*b1^3*q1*v*C2+6960*v^3*b1^2*q1^2*C2+4320*v^6*C3+23040*v^5*C4+240*b1^2*q1^2*v^2*av1*C1-720*C1*v^6*r-46080*b1*q1*VC4*v^4-480*v^4*b1*q1*av1*C1+2880*v^5*b1^2*q1^2*VVC2+480*b1*z^4*q1*C1*f^3-3000*b1^2*z^4*q1^2*av*v*C1-720*b1*z^4*v^3*q1*av*C1-60*b1*z^4*v^6*q1*C1+11760*b1^3*z^4*q1^3*C1*f-4440*b1^2*z^4*q1^2*C1*f^2-4560*b1^3*z^4*q1*C1*f-480*b1^2*z^4*v^2*C1*f+3000*b1^2*z^4*v^2*q1^2*C1*f-1440*b1^2*z^4*q1^2*C2*v*f+1440*b1*z^4*q1*br*q2*v*C1*f+1440*b1*z^4*q1*av*v*C1*f-720*b1^2*z^4*v^2*q1^2*C1*r-576*b1^4*z^4*C1+46080*C5*v^4+5760*C5*v^4*z^4+51840*C5*v^4*z^2+240*b1^2*v^2*av1*C1-53760*b1^3*q1*v^2*VC2+120*C1*v^6*f-69120*b1^2*q1^2*v^3*VC3-1320*b1^2*q1^2*br*q2*v*C1+360*b1*z^4*v^4*q1*C1*f-720*b1*z^4*v^2*q1*C1*f^2+2880*r^2*v^4*C1-22560*b1^2*q1^2*br*q2*v^2*RC2+240*v^3*b1*q1*br*q2*C1+720*b1*q1*br*q2^2*v^2*br1*C1-480*b1^2*v^2*r*C1+9600*b1*q1*v^3*av1*C2-5760*b1*q1*v^4*av1*VC2-17280*av*v^3*C3-1440*br*q2*v*C1*f^2-1440*v^3*br*q2*C1*f+23040*b1*q1*br*q2*v^2*RC2*f-960*br*q2^2*v^2*br1*C1*f-480*av*v*b1^2*C1+120*b1^2*q1^2*av*v*C1-720*v^3*b1*q1*av*C1-5760*v^4*b1^2*q1^2*VC2+720*b1^2*C1*f^2-360*v^4*C1*f^2+23040*b1^2*q1^2*VC2*v^2*f-2880*av*v^3*r*C1+60*v^2*b1^3*q1^3*C1-564*b1^4*q1^2*C1+1080*v^5*av*C1+240*av^2*v^2*C1+11520*av*v^4*VC3+5760*v^5*av*VC2-2880*v^4*av*C2+177*b1^4*q1^4*C1-240*b1^3*z^6*q1^3*C2*v+360*b1^2*z^6*q1^2*av*v*C1+480*b1^3*z^6*q1*C1*f+360*b1^2*z^6*q1^2*br*q2*v*C1-5760*z^2*v^4*C3*r+34560*z^2*b1^2*v^2*C3-120*z^2*C1*v^6*f-17280*z^2*av*v^3*C3-2160*z^2*b1^2*C1*f^2+360*z^2*v^4*C1*f^2-2652*z^2*b1^4*q1^2*C1+360*z^2*v^5*av*C1+720*z^2*av^2*v^2*C1+5760*z^2*av*v^4*VC3+3771*z^2*b1^4*q1^4*C1+2880*z^2*br^2*v^4*RRC3+2880*z^2*b1^2*VVC3*v^4-17280*z^2*b1^2*VC3*v^3+420*z^2*v^4*b1^2*C1+5760*z^2*ar*v^4*RC3-480*z^2*v^2*C1*f^3-23040*z^2*C4*v^3*f+960*z^2*v^3*b1^2*C2+11520*z^2*v^5*C4+480*b1^2*v^3*av2*C1+28800*b1*q1*v^3*av*VC2-37440*b1*q1*v^2*av*C2+27600*b1^3*q1^3*C2*v+120*v^2*b1^2*q1^2*C1*f-1920*q3*br*b1*v*C1*f-5760*br*q2*v^2*C2*f+5760*v^4*br*q2*RC2*f+115200*b1*q1*C4*v^3+960*av*v^3*av1*C1+720*b1^2*q1*q3*br*v*C1+5760*br^2*v^4*RRC3+960*br^2*v^2*C1-5760*br^2*v^3*RC2-22560*b1^3*q1^3*VC2*v^2+10080*z^2*b1^3*q1*v*C2-5280*z^2*v^3*b1^2*q1^2*C2-1680*z^2*b1^2*q1^2*v^2*av1*C1-23040*z^2*b1*q1*VC4*v^4-480*z^2*v^4*b1*q1*av1*C1+720*z^2*b1^2*v^2*av1*C1-4800*z^2*b1^3*q1*v^2*VC2+7800*z^2*b1^2*q1^2*br*q2*v*C1-1440*z^2*br*q2*v*b1^2*C1+13440*z^2*b1^2*q1^2*br*q2*v^2*RC2+960*z^2*v^3*b1*q1*br*q2*C1-2160*z^2*b1*q1*br*q2^2*v^2*br1*C1-960*z^2*b1^2*v^2*r*C1+1440*z^2*br*q2*v*C1*f^2-1440*z^2*v^3*br*q2*C1*f-5760*z^2*b1*q1*br*q2*v^2*RC2*f+960*z^2*br*q2^2*v^2*br1*C1*f-960*z^2*av*v*b1^2*C1+3480*z^2*b1^2*q1^2*av*v*C1+2880*z^2*v^4*b1^2*q1^2*VC2-5760*z^2*b1^2*q1^2*VC2*v^2*f+840*z^2*v^2*b1^3*q1^3*C1-2880*z^2*b1*q1*v^2*av*C2-22320*z^2*b1^3*q1^3*C2*v-3720*z^2*v^2*b1^2*q1^2*C1*f+92160*z^2*b1*q1*C4*v^3-720*z^2*b1^2*q1*q3*br*v*C1+13440*z^2*b1^3*q1^3*VC2*v^2-720*z^2*v^5*b1*q1*C2+16320*z^2*b1^2*q1^2*C2*v*f-720*z^2*v^4*b1*q1*C1*f-5760*br*q2^2*v^3*br1*RC2*f-5760*b1^2*q1^2*v^3*VVC2*f-86400*v^2*b1*q1*C3*f-17280*v^4*C3*f+17280*v^2*C3*f^2-1920*C2*v*f^3+2880*v^3*C2*f^2-1440*C2*v^5*f+80*b1^4*z^6*C1+15*z^2*v^8*C1+240*z^2*C1*f^4+276*z^2*b1^4*C1+720*v^5*b1*q1*C2-11520*b1*q1*v^4*av*VVC2-15*v^8*C1+240*v^7*C2-60*b1^3*q1^3*C1*z^8*v^2+120*b1^3*q1^3*C1*z^8*f+360*b1^2*z^6*q1^2*C1*f^2+840*b1^3*z^6*v^2*q1^3*C1+90*b1^2*z^6*v^4*q1^2*C1-2400*b1^3*z^6*q1^3*C1*f+3530*b1^4*z^6*q1^4*C1-35040*b1^2*q1^2*C2*v*f+3360*b1*q1*br*q2*v*C1*f+1440*b1*q1*av*v*C1*f+2880*b1*q1*v^2*r*C1*f-360*v^4*b1*q1*C1*f-720*v^2*b1*q1*C1*f^2+14400*b1*q1*C2*v*f^2-960*b1*q1*v^2*av1*C1*f+110880*b1^2*q1^2*v^2*C3+12480*b1*q1*br*q2*v^2*C2-720*br^2*q2^2*v^2*C1+1080*v^5*br*q2*C1-17280*v^5*br*q2*RC3-8640*v^3*b1*q1*C2*f+11520*v^3*C2*r*f-5760*v^3*b1^2*VVC2*f+17280*v^2*b1^2*VC2*f-11520*v^3*av*VC2*f+17280*v^2*av*C2*f-11520*v^3*ar*RC2*f+2880*ar*v^2*C1*f+120*v^2*b1^3*q1*C1-17280*b1*q1*v^3*C2*r-240*C1*f^4+8640*b1^3*q1^3*v^3*VVC2+25920*v^4*b1*q1*C3-7680*z^2*b1*q1*br*q2*v*C1*f-5760*z^2*b1*q1*av*v*C1*f-2880*z^2*b1*q1*v^2*r*C1*f+2880*z^2*v^2*b1*q1*C1*f^2-2880*z^2*b1*q1*C2*v*f^2+960*z^2*b1*q1*v^2*av1*C1*f+4320*z^2*b1^2*q1^2*v^2*C3-2880*z^2*b1*q1*br*q2*v^2*C2+720*z^2*br^2*q2^2*v^2*C1+360*z^2*v^5*br*q2*C1+2880*z^2*v^3*b1*q1*C2*f-2880*z^2*b1^3*q1^3*v^3*VVC2-30*z^2*v^4*b1^2*q1^2*C1-480*z^2*v^4*br*q2^2*br1*C1-2880*z^2*b1*q1*br*q2^2*v^3*br1*RC2+240*z^2*br*q2^3*v^3*br1^2*C1+1440*z^2*br*q2*v^2*av*C1-1920*z^2*br*q2*v^2*b1^2*RC2+5760*z^2*q3*br*b1*VRC3*v^4+2880*z^2*v^4*b1*q1*br*q2*RC2+240*z^2*br^2*q2^3*v^3*br2*C1+6720*z^2*b1^3*q1*C1*f+240*z^2*v^2*b1^2*C1*f-2880*z^2*b1*q1*C1*f^3-1440*z^2*av*v^3*C1*f+1440*z^2*av*v*C1*f^2-1920*z^2*v*b1^2*C2*f+2400*z^2*v^2*b1^2*q1^2*C1*r+1440*z^2*b1*q1*ar*v^2*C1+1440*z^2*v^4*b1*q1*r*C1-150*v^4*b1^2*q1^2*C1+252*b1^4*C1+5760*b1^2*VVC3*v^4-480*v^4*br*q2^2*br1*C1+8640*b1*q1*br*q2^2*v^3*br1*RC2-240*br*q2^3*v^3*br1^2*C1-5760*q3*br*b1*v^3*VC2-480*br*q2*v^2*av*C1-16320*br*q2*v^2*b1^2*RC2+11520*q3*br*b1*VRC3*v^4-2880*v^3*br*q2*C1*r-5760*v^4*b1*q1*br*q2*RC2-240*br^2*q2^3*v^3*br2*C1-17280*b1^2*VC3*v^3+17280*br^2*q2^2*v^4*RRC3+900*v^4*b1^2*C1-1440*v^6*b1*q1*VC2-240*b1^3*q1*C1*f-240*v^2*b1^2*C1*f+1440*b1*q1*C1*f^3-1440*av*v^3*C1*f-1440*av*v*C1*f^2-24000*v*b1^2*C2*f+180*v^6*b1*q1*C1-240*v^2*b1^2*q1^2*C1*r+11520*ar*v^4*RC3+5760*v^5*ar*RC2-4320*ar*v^4*C1-5760*ar*v^3*C2-1440*b1*q1*ar*v^2*C1+1440*v^4*b1*q1*r*C1-9600*q3*br*b1^2*v^2*q1*RC2+8640*br*q2*v^4*C2-1440*v^6*br*q2*RC2-5760*br^2*q2^2*v^3*RC2+17280*br*q2*v^3*C3-5760*v^5*C2*r+17280*b1*q1*v^3*ar*RC2-69120*b1*q1*v^3*br*q2*RC3+11520*br*q2*v^3*av*RC2+34560*b1*q1*v^4*br*q2*VRC3+2880*q3*br*b1*v^4*RC2-5760*br*q2*v^4*ar1*RC2-5760*b1*q1*br*q2*v^3*VC2+960*br*q2*v^3*ar1*C1+11520*br*q2*v^4*RC2*r+34560*v^3*b1*q1*VC3*f-5760*b1*q1*VC2*v^2*f^2+5760*v^4*b1*q1*VC2*f-5760*br*q2*v^2*RC2*f^2+5760*q3*br*b1*v^2*RC2*f+34560*v^3*br*q2*RC3*f-435*b1^4*q1^4*C1*z^8+120*b1^4*q1^2*C1*z^8-1900*b1^4*z^6*q1^2*C1+480*v^2*C1*f^3-46080*C4*v^3*f+7200*v^3*b1^2*C2-1920*br^2*q2^3*v^4*br2*RC2+480*br^2*v^3*br2*q2*C1-2880*br^2*v^4*br2*q2*RC2-3840*q3*br*b1*v^3*C1+5760*q3*br*b1*v^2*C2+2880*v^5*br*q2^2*br1*RC2+17280*br*q2^2*v^4*br1*RC3-1920*br*q2^3*v^4*br1^2*RC2-1920*br*q2^2*v^3*br1*C2+20160*b1^3*q1*v^3*VVC2+240*z^2*b1^2*q1^2*v^3*av2*C1-12960*z^2*b1^3*q1^3*C1*f+10440*z^2*b1^2*q1^2*C1*f^2-23040*z^2*br*q2*v^4*RC4-960*b1^3*z^4*q1*v*C2+720*b1^2*z^4*v^3*q1^2*C2+480*b1^2*z^4*av*v*C1-2400*b1^3*z^4*v^2*q1^3*C1+4560*b1^3*z^4*q1^3*C2*v-1440*b1^3*z^4*q1^3*VC2*v^2+840*b1^3*z^4*v^2*q1*C1-390*b1^2*z^4*v^4*q1^2*C1+480*b1^2*z^4*q1^2*v^2*av1*C1-3960*b1^2*z^4*q1^2*br*q2*v*C1+480*b1^2*z^4*br*q2*v*C1-1440*b1^2*z^4*q1^2*br*q2*v^2*RC2-720*b1*z^4*v^3*q1*br*q2*C1+480*b1*z^4*q1*br*q2^2*v^2*br1*C1-8466*b1^4*z^4*q1^4*C1+480*b1^2*z^4*C1*f^2+6372*b1^4*z^4*q1^2*C1+120*b1^2*z^4*v^4*C1+11520*b1*q1*v^4*VC2*r-2880*v^4*b1^2*VC2-240*b1^3*z^6*v^2*q1*C1-360*b1^2*z^6*v^2*q1^2*C1*f+17280*b1^2*q1^2*v^4*VVC3-240*b1^2*q1^2*v^3*av2*C1+960*ar*v^3*br1*q2*C1+15*b1^4*q1^4*C1*z^10+2880*v^4*C1*r*f-2880*v^2*C1*r*f^2+1080*b1^3*q1^3*C1*f-2520*b1^2*q1^2*C1*f^2-5760*ar*v^4*br1*q2*RC2-46080*br*q2*v^4*RC4)/v^4;
PN5=1/4*z*(8*b1*q1*v^2*av1*C2-4*b1*q1*v^3*av1*VC2+28*b1*q1*v^2*av*VC2-40*b1*q1*v*av*C2-8*b1*q1*v^3*av*VVC2-16*b1*q1*v^2*C2*r+24*v^3*b1*q1*C3+12*br^2*q2^2*v^3*RRC3+4*br*q2*v^3*C2+12*br*q2*v^2*C3+20*b1^3*q1*v^2*VVC2+6*b1^2*VVC3*v^3-4*q3*br*b1*v^2*VC2-16*br*q2*v*b1^2*RC2+12*q3*br*b1*VRC3*v^3+4*v^4*ar*RC2-2*ar*v^3*C1-4*ar*v^2*C2-4*v^4*C2*r+6*v^2*b1^2*C2-4*v^3*b1^2*VC2-24*b1^2*C2*f-48*C4*v^2*f-12*v^3*C3*f+12*v*C3*f^2+8*z^2*v^4*C4+4*C5*v^3*z^4+40*C5*v^3*z^2+24*v^2*b1*q1*VC3*f+4*q3*br*b1*v*RC2*f+24*v^2*br*q2*RC3*f-16*z^2*v^3*br*q2*RC4-12*z^2*v^2*b1^2*VC3+2*z^2*v^3*br^2*RRC3-16*z^2*v^2*C4*f+4*z^2*v^3*q3*br*b1*VRC3-4*z^2*v^3*C3*r+4*z^2*v^3*ar*RC3+4*z^2*v^3*av*VC3-12*z^2*v^2*av*C3+24*z^2*v*b1^2*C3+2*z^2*v^3*b1^2*VVC3+60*C5*v^3-8*q3*br*b1^2*v*q1*RC2+16*b1*q1*v^2*ar*RC2-60*b1*q1*v^2*br*q2*RC3+12*br*q2*v^2*av*RC2+24*b1*q1*v^3*br*q2*VRC3+2*q3*br*b1*v^3*RC2-4*br*q2*v^3*ar1*RC2+8*br*q2*v^3*RC2*r-2*br^2*v^3*br2*q2*RC2-2*q3*br*b1*v^2*C1+4*q3*br*b1*v*C2+12*br*q2^2*v^3*br1*RC3+12*b1^2*q1^2*v^3*VVC3-48*br*q2*v^3*RC4+16*v*b1^2*VC2*f-8*v^2*av*VC2*f+16*v*av*C2*f-8*v^2*ar*RC2*f+8*v^2*C2*r*f-4*v^2*b1^2*VVC2*f+8*b1*q1*v^3*VC2*r-4*ar*v^3*br1*q2*RC2-72*v*b1*q1*C3*f-12*v^4*b1*q1*VC3+72*b1^3*q1*C2-48*b1*q1*VC4*v^3-56*b1^3*q1*v*VC2-60*b1^2*q1^2*v^2*VC3+144*b1*q1*C4*v^2+108*b1^2*q1^2*v*C3-12*v^4*br*q2*RC3-12*v^3*C3*r+42*b1^2*v*C3+2*v^4*b1^2*VVC2+2*r^2*v^3*C1-24*av*v^2*C3+12*av*v^3*VC3+4*v^4*av*VC2-4*v^3*av*C2+6*br^2*v^3*RRC3-4*br^2*v^2*RC2-24*b1^2*VC3*v^2+12*ar*v^3*RC3-16*z^2*v^3*b1*q1*VC4+64*z^2*v^2*b1*q1*C4+3*v^5*C3+24*v^4*C4)/v^3;

%Option price
P=(Pn1*n+PN1*N)*sqrt(t)+(Pn2*n+PN2*N)*t+(Pn3*n+PN3*N)*sqrt(t)*t+(Pn4*n+PN4*N)*t^2+(Pn5*n+PN5*N)*sqrt(t)*t^2;
   

P_SVSI=P;

%EOF